@@ -7,7 +7,7 @@ import serial
 import serial.threaded
 import threading
 import logging
-from Queue import Queue
+from queue import Queue
 
 
 class Protocol(serial.threaded.Protocol):
